drop_thin_vec

Function drop_thin_vec 

pub(crate) unsafe fn drop_thin_vec<T>(this: &mut ThinVec<T>)
Safety

This function drop and deallocates the inner values of the ThinVec, invariants are therefore broken and the value must be considered dropped and should not be accessed again.